@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.vision_v1p1beta1.types import geometry
@@ -56,6 +60,25 @@ __protobuf__ = proto.module(
 class Likelihood(proto.Enum):
     r"""A bucketized representation of likelihood, which is intended
     to give clients highly stable results across model upgrades.
+
+    Values:
+        UNKNOWN (0):
+            Unknown likelihood.
+        VERY_UNLIKELY (1):
+            It is very unlikely that the image belongs to
+            the specified vertical.
+        UNLIKELY (2):
+            It is unlikely that the image belongs to the
+            specified vertical.
+        POSSIBLE (3):
+            It is possible that the image belongs to the
+            specified vertical.
+        LIKELY (4):
+            It is likely that the image belongs to the
+            specified vertical.
+        VERY_LIKELY (5):
+            It is very likely that the image belongs to
+            the specified vertical.
     """
     UNKNOWN = 0
     VERY_UNLIKELY = 1
@@ -78,13 +101,43 @@ class Feature(proto.Message):
         max_results (int):
             Maximum number of results of this type.
         model (str):
-            Model to use for the feature.
-            Supported values: "builtin/stable" (the default
-            if unset) and "builtin/latest".
+            Model to use for the feature. Supported values:
+            "builtin/stable" (the default if unset) and
+            "builtin/latest". ``DOCUMENT_TEXT_DETECTION`` and
+            ``TEXT_DETECTION`` also support "builtin/weekly" for the
+            bleeding edge release updated weekly.
     """
 
     class Type(proto.Enum):
-        r"""Type of image feature."""
+        r"""Type of image feature.
+
+        Values:
+            TYPE_UNSPECIFIED (0):
+                Unspecified feature type.
+            FACE_DETECTION (1):
+                Run face detection.
+            LANDMARK_DETECTION (2):
+                Run landmark detection.
+            LOGO_DETECTION (3):
+                Run logo detection.
+            LABEL_DETECTION (4):
+                Run label detection.
+            TEXT_DETECTION (5):
+                Run OCR.
+            DOCUMENT_TEXT_DETECTION (11):
+                Run dense text document OCR. Takes precedence when both
+                DOCUMENT_TEXT_DETECTION and TEXT_DETECTION are present.
+            SAFE_SEARCH_DETECTION (6):
+                Run computer vision models to compute image
+                safe-search properties.
+            IMAGE_PROPERTIES (7):
+                Compute a set of image properties, such as
+                the image's dominant colors.
+            CROP_HINTS (9):
+                Run crop hints.
+            WEB_DETECTION (10):
+                Run web detection.
+        """
         TYPE_UNSPECIFIED = 0
         FACE_DETECTION = 1
         LANDMARK_DETECTION = 2
@@ -97,16 +150,16 @@ class Feature(proto.Message):
         CROP_HINTS = 9
         WEB_DETECTION = 10
 
-    type_ = proto.Field(
+    type_: Type = proto.Field(
         proto.ENUM,
         number=1,
         enum=Type,
     )
-    max_results = proto.Field(
+    max_results: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    model = proto.Field(
+    model: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -137,11 +190,11 @@ class ImageSource(proto.Message):
                ``image_uri`` takes precedence.
     """
 
-    gcs_image_uri = proto.Field(
+    gcs_image_uri: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    image_uri = proto.Field(
+    image_uri: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -162,11 +215,11 @@ class Image(proto.Message):
             request.
     """
 
-    content = proto.Field(
+    content: bytes = proto.Field(
         proto.BYTES,
         number=1,
     )
-    source = proto.Field(
+    source: "ImageSource" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="ImageSource",
@@ -195,7 +248,7 @@ class FaceAnnotation(proto.Message):
             an image. It is not based on the landmarker results, only on
             the initial face detection, hence the fd (face detection)
             prefix.
-        landmarks (Sequence[google.cloud.vision_v1p1beta1.types.FaceAnnotation.Landmark]):
+        landmarks (MutableSequence[google.cloud.vision_v1p1beta1.types.FaceAnnotation.Landmark]):
             Detected face landmarks.
         roll_angle (float):
             Roll angle, which indicates the amount of
@@ -245,6 +298,79 @@ class FaceAnnotation(proto.Message):
             vantage of the viewer of the image without considering mirror
             projections typical of photos. So, ``LEFT_EYE``, typically, is the
             person's right eye.
+
+            Values:
+                UNKNOWN_LANDMARK (0):
+                    Unknown face landmark detected. Should not be
+                    filled.
+                LEFT_EYE (1):
+                    Left eye.
+                RIGHT_EYE (2):
+                    Right eye.
+                LEFT_OF_LEFT_EYEBROW (3):
+                    Left of left eyebrow.
+                RIGHT_OF_LEFT_EYEBROW (4):
+                    Right of left eyebrow.
+                LEFT_OF_RIGHT_EYEBROW (5):
+                    Left of right eyebrow.
+                RIGHT_OF_RIGHT_EYEBROW (6):
+                    Right of right eyebrow.
+                MIDPOINT_BETWEEN_EYES (7):
+                    Midpoint between eyes.
+                NOSE_TIP (8):
+                    Nose tip.
+                UPPER_LIP (9):
+                    Upper lip.
+                LOWER_LIP (10):
+                    Lower lip.
+                MOUTH_LEFT (11):
+                    Mouth left.
+                MOUTH_RIGHT (12):
+                    Mouth right.
+                MOUTH_CENTER (13):
+                    Mouth center.
+                NOSE_BOTTOM_RIGHT (14):
+                    Nose, bottom right.
+                NOSE_BOTTOM_LEFT (15):
+                    Nose, bottom left.
+                NOSE_BOTTOM_CENTER (16):
+                    Nose, bottom center.
+                LEFT_EYE_TOP_BOUNDARY (17):
+                    Left eye, top boundary.
+                LEFT_EYE_RIGHT_CORNER (18):
+                    Left eye, right corner.
+                LEFT_EYE_BOTTOM_BOUNDARY (19):
+                    Left eye, bottom boundary.
+                LEFT_EYE_LEFT_CORNER (20):
+                    Left eye, left corner.
+                RIGHT_EYE_TOP_BOUNDARY (21):
+                    Right eye, top boundary.
+                RIGHT_EYE_RIGHT_CORNER (22):
+                    Right eye, right corner.
+                RIGHT_EYE_BOTTOM_BOUNDARY (23):
+                    Right eye, bottom boundary.
+                RIGHT_EYE_LEFT_CORNER (24):
+                    Right eye, left corner.
+                LEFT_EYEBROW_UPPER_MIDPOINT (25):
+                    Left eyebrow, upper midpoint.
+                RIGHT_EYEBROW_UPPER_MIDPOINT (26):
+                    Right eyebrow, upper midpoint.
+                LEFT_EAR_TRAGION (27):
+                    Left ear tragion.
+                RIGHT_EAR_TRAGION (28):
+                    Right ear tragion.
+                LEFT_EYE_PUPIL (29):
+                    Left eye pupil.
+                RIGHT_EYE_PUPIL (30):
+                    Right eye pupil.
+                FOREHEAD_GLABELLA (31):
+                    Forehead glabella.
+                CHIN_GNATHION (32):
+                    Chin gnathion.
+                CHIN_LEFT_GONION (33):
+                    Chin left gonion.
+                CHIN_RIGHT_GONION (34):
+                    Chin right gonion.
             """
             UNKNOWN_LANDMARK = 0
             LEFT_EYE = 1
@@ -282,83 +408,83 @@ class FaceAnnotation(proto.Message):
             CHIN_LEFT_GONION = 33
             CHIN_RIGHT_GONION = 34
 
-        type_ = proto.Field(
+        type_: "FaceAnnotation.Landmark.Type" = proto.Field(
             proto.ENUM,
             number=3,
             enum="FaceAnnotation.Landmark.Type",
         )
-        position = proto.Field(
+        position: geometry.Position = proto.Field(
             proto.MESSAGE,
             number=4,
             message=geometry.Position,
         )
 
-    bounding_poly = proto.Field(
+    bounding_poly: geometry.BoundingPoly = proto.Field(
         proto.MESSAGE,
         number=1,
         message=geometry.BoundingPoly,
     )
-    fd_bounding_poly = proto.Field(
+    fd_bounding_poly: geometry.BoundingPoly = proto.Field(
         proto.MESSAGE,
         number=2,
         message=geometry.BoundingPoly,
     )
-    landmarks = proto.RepeatedField(
+    landmarks: MutableSequence[Landmark] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message=Landmark,
     )
-    roll_angle = proto.Field(
+    roll_angle: float = proto.Field(
         proto.FLOAT,
         number=4,
     )
-    pan_angle = proto.Field(
+    pan_angle: float = proto.Field(
         proto.FLOAT,
         number=5,
     )
-    tilt_angle = proto.Field(
+    tilt_angle: float = proto.Field(
         proto.FLOAT,
         number=6,
     )
-    detection_confidence = proto.Field(
+    detection_confidence: float = proto.Field(
         proto.FLOAT,
         number=7,
     )
-    landmarking_confidence = proto.Field(
+    landmarking_confidence: float = proto.Field(
         proto.FLOAT,
         number=8,
     )
-    joy_likelihood = proto.Field(
+    joy_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=9,
         enum="Likelihood",
     )
-    sorrow_likelihood = proto.Field(
+    sorrow_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=10,
         enum="Likelihood",
     )
-    anger_likelihood = proto.Field(
+    anger_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=11,
         enum="Likelihood",
     )
-    surprise_likelihood = proto.Field(
+    surprise_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=12,
         enum="Likelihood",
     )
-    under_exposed_likelihood = proto.Field(
+    under_exposed_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=13,
         enum="Likelihood",
     )
-    blurred_likelihood = proto.Field(
+    blurred_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=14,
         enum="Likelihood",
     )
-    headwear_likelihood = proto.Field(
+    headwear_likelihood: "Likelihood" = proto.Field(
         proto.ENUM,
         number=15,
         enum="Likelihood",
@@ -373,7 +499,7 @@ class LocationInfo(proto.Message):
             lat/long location coordinates.
     """
 
-    lat_lng = proto.Field(
+    lat_lng: latlng_pb2.LatLng = proto.Field(
         proto.MESSAGE,
         number=1,
         message=latlng_pb2.LatLng,
@@ -392,15 +518,15 @@ class Property(proto.Message):
             Value of numeric properties.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    value = proto.Field(
+    value: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    uint64_value = proto.Field(
+    uint64_value: int = proto.Field(
         proto.UINT64,
         number=3,
     )
@@ -437,54 +563,54 @@ class EntityAnnotation(proto.Message):
         bounding_poly (google.cloud.vision_v1p1beta1.types.BoundingPoly):
             Image region to which this entity belongs. Not produced for
             ``LABEL_DETECTION`` features.
-        locations (Sequence[google.cloud.vision_v1p1beta1.types.LocationInfo]):
+        locations (MutableSequence[google.cloud.vision_v1p1beta1.types.LocationInfo]):
             The location information for the detected entity. Multiple
             ``LocationInfo`` elements can be present because one
             location may indicate the location of the scene in the
             image, and another location may indicate the location of the
             place where the image was taken. Location information is
             usually present for landmarks.
-        properties (Sequence[google.cloud.vision_v1p1beta1.types.Property]):
+        properties (MutableSequence[google.cloud.vision_v1p1beta1.types.Property]):
             Some entities may have optional user-supplied ``Property``
             (name/value) fields, such a score or string that qualifies
             the entity.
     """
 
-    mid = proto.Field(
+    mid: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    locale = proto.Field(
+    locale: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    score = proto.Field(
+    score: float = proto.Field(
         proto.FLOAT,
         number=4,
     )
-    confidence = proto.Field(
+    confidence: float = proto.Field(
         proto.FLOAT,
         number=5,
     )
-    topicality = proto.Field(
+    topicality: float = proto.Field(
         proto.FLOAT,
         number=6,
     )
-    bounding_poly = proto.Field(
+    bounding_poly: geometry.BoundingPoly = proto.Field(
         proto.MESSAGE,
         number=7,
         message=geometry.BoundingPoly,
     )
-    locations = proto.RepeatedField(
+    locations: MutableSequence["LocationInfo"] = proto.RepeatedField(
         proto.MESSAGE,
         number=8,
         message="LocationInfo",
     )
-    properties = proto.RepeatedField(
+    properties: MutableSequence["Property"] = proto.RepeatedField(
         proto.MESSAGE,
         number=9,
         message="Property",
@@ -520,27 +646,27 @@ class SafeSearchAnnotation(proto.Message):
             body areas.
     """
 
-    adult = proto.Field(
+    adult: "Likelihood" = proto.Field(
         proto.ENUM,
         number=1,
         enum="Likelihood",
     )
-    spoof = proto.Field(
+    spoof: "Likelihood" = proto.Field(
         proto.ENUM,
         number=2,
         enum="Likelihood",
     )
-    medical = proto.Field(
+    medical: "Likelihood" = proto.Field(
         proto.ENUM,
         number=3,
         enum="Likelihood",
     )
-    violence = proto.Field(
+    violence: "Likelihood" = proto.Field(
         proto.ENUM,
         number=4,
         enum="Likelihood",
     )
-    racy = proto.Field(
+    racy: "Likelihood" = proto.Field(
         proto.ENUM,
         number=9,
         enum="Likelihood",
@@ -557,12 +683,12 @@ class LatLongRect(proto.Message):
             Max lat/long pair.
     """
 
-    min_lat_lng = proto.Field(
+    min_lat_lng: latlng_pb2.LatLng = proto.Field(
         proto.MESSAGE,
         number=1,
         message=latlng_pb2.LatLng,
     )
-    max_lat_lng = proto.Field(
+    max_lat_lng: latlng_pb2.LatLng = proto.Field(
         proto.MESSAGE,
         number=2,
         message=latlng_pb2.LatLng,
@@ -583,16 +709,16 @@ class ColorInfo(proto.Message):
             Value in range [0, 1].
     """
 
-    color = proto.Field(
+    color: color_pb2.Color = proto.Field(
         proto.MESSAGE,
         number=1,
         message=color_pb2.Color,
     )
-    score = proto.Field(
+    score: float = proto.Field(
         proto.FLOAT,
         number=2,
     )
-    pixel_fraction = proto.Field(
+    pixel_fraction: float = proto.Field(
         proto.FLOAT,
         number=3,
     )
@@ -602,12 +728,12 @@ class DominantColorsAnnotation(proto.Message):
     r"""Set of dominant colors and their corresponding scores.
 
     Attributes:
-        colors (Sequence[google.cloud.vision_v1p1beta1.types.ColorInfo]):
+        colors (MutableSequence[google.cloud.vision_v1p1beta1.types.ColorInfo]):
             RGB color values with their score and pixel
             fraction.
     """
 
-    colors = proto.RepeatedField(
+    colors: MutableSequence["ColorInfo"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="ColorInfo",
@@ -623,7 +749,7 @@ class ImageProperties(proto.Message):
             successfully.
     """
 
-    dominant_colors = proto.Field(
+    dominant_colors: "DominantColorsAnnotation" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="DominantColorsAnnotation",
@@ -646,16 +772,16 @@ class CropHint(proto.Message):
             with respect to the original image.
     """
 
-    bounding_poly = proto.Field(
+    bounding_poly: geometry.BoundingPoly = proto.Field(
         proto.MESSAGE,
         number=1,
         message=geometry.BoundingPoly,
     )
-    confidence = proto.Field(
+    confidence: float = proto.Field(
         proto.FLOAT,
         number=2,
     )
-    importance_fraction = proto.Field(
+    importance_fraction: float = proto.Field(
         proto.FLOAT,
         number=3,
     )
@@ -666,11 +792,11 @@ class CropHintsAnnotation(proto.Message):
     serving images.
 
     Attributes:
-        crop_hints (Sequence[google.cloud.vision_v1p1beta1.types.CropHint]):
+        crop_hints (MutableSequence[google.cloud.vision_v1p1beta1.types.CropHint]):
             Crop hint results.
     """
 
-    crop_hints = proto.RepeatedField(
+    crop_hints: MutableSequence["CropHint"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="CropHint",
@@ -681,7 +807,7 @@ class CropHintsParams(proto.Message):
     r"""Parameters for crop hints annotation request.
 
     Attributes:
-        aspect_ratios (Sequence[float]):
+        aspect_ratios (MutableSequence[float]):
             Aspect ratios in floats, representing the
             ratio of the width to the height of the image.
             For example, if the desired aspect ratio is 4/3,
@@ -692,7 +818,7 @@ class CropHintsParams(proto.Message):
             provided after the 16th are ignored.
     """
 
-    aspect_ratios = proto.RepeatedField(
+    aspect_ratios: MutableSequence[float] = proto.RepeatedField(
         proto.FLOAT,
         number=1,
     )
@@ -707,7 +833,7 @@ class WebDetectionParams(proto.Message):
             geo information in the image.
     """
 
-    include_geo_results = proto.Field(
+    include_geo_results: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
@@ -722,16 +848,16 @@ class TextDetectionParams(proto.Message):
             By default, Cloud Vision API only includes confidence score
             for DOCUMENT_TEXT_DETECTION result. Set the flag to true to
             include confidence score for TEXT_DETECTION as well.
-        advanced_ocr_options (Sequence[str]):
+        advanced_ocr_options (MutableSequence[str]):
             A list of advanced OCR options to fine-tune
             OCR behavior.
     """
 
-    enable_text_detection_confidence_score = proto.Field(
+    enable_text_detection_confidence_score: bool = proto.Field(
         proto.BOOL,
         number=9,
     )
-    advanced_ocr_options = proto.RepeatedField(
+    advanced_ocr_options: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=11,
     )
@@ -744,7 +870,7 @@ class ImageContext(proto.Message):
         lat_long_rect (google.cloud.vision_v1p1beta1.types.LatLongRect):
             lat/long rectangle that specifies the
             location of the image.
-        language_hints (Sequence[str]):
+        language_hints (MutableSequence[str]):
             List of languages to use for TEXT_DETECTION. In most cases,
             an empty value yields the best results since it enables
             automatic language detection. For languages based on the
@@ -764,26 +890,26 @@ class ImageContext(proto.Message):
             text detection.
     """
 
-    lat_long_rect = proto.Field(
+    lat_long_rect: "LatLongRect" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="LatLongRect",
     )
-    language_hints = proto.RepeatedField(
+    language_hints: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=2,
     )
-    crop_hints_params = proto.Field(
+    crop_hints_params: "CropHintsParams" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="CropHintsParams",
     )
-    web_detection_params = proto.Field(
+    web_detection_params: "WebDetectionParams" = proto.Field(
         proto.MESSAGE,
         number=6,
         message="WebDetectionParams",
     )
-    text_detection_params = proto.Field(
+    text_detection_params: "TextDetectionParams" = proto.Field(
         proto.MESSAGE,
         number=12,
         message="TextDetectionParams",
@@ -797,24 +923,24 @@ class AnnotateImageRequest(proto.Message):
     Attributes:
         image (google.cloud.vision_v1p1beta1.types.Image):
             The image to be processed.
-        features (Sequence[google.cloud.vision_v1p1beta1.types.Feature]):
+        features (MutableSequence[google.cloud.vision_v1p1beta1.types.Feature]):
             Requested features.
         image_context (google.cloud.vision_v1p1beta1.types.ImageContext):
             Additional context that may accompany the
             image.
     """
 
-    image = proto.Field(
+    image: "Image" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="Image",
     )
-    features = proto.RepeatedField(
+    features: MutableSequence["Feature"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="Feature",
     )
-    image_context = proto.Field(
+    image_context: "ImageContext" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="ImageContext",
@@ -825,19 +951,19 @@ class AnnotateImageResponse(proto.Message):
     r"""Response to an image annotation request.
 
     Attributes:
-        face_annotations (Sequence[google.cloud.vision_v1p1beta1.types.FaceAnnotation]):
+        face_annotations (MutableSequence[google.cloud.vision_v1p1beta1.types.FaceAnnotation]):
             If present, face detection has completed
             successfully.
-        landmark_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
+        landmark_annotations (MutableSequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, landmark detection has completed
             successfully.
-        logo_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
+        logo_annotations (MutableSequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, logo detection has completed
             successfully.
-        label_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
+        label_annotations (MutableSequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, label detection has completed
             successfully.
-        text_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
+        text_annotations (MutableSequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, text (OCR) detection has
             completed successfully.
         full_text_annotation (google.cloud.vision_v1p1beta1.types.TextAnnotation):
@@ -863,57 +989,57 @@ class AnnotateImageResponse(proto.Message):
             correct, even when ``error`` is set.
     """
 
-    face_annotations = proto.RepeatedField(
+    face_annotations: MutableSequence["FaceAnnotation"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="FaceAnnotation",
     )
-    landmark_annotations = proto.RepeatedField(
+    landmark_annotations: MutableSequence["EntityAnnotation"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="EntityAnnotation",
     )
-    logo_annotations = proto.RepeatedField(
+    logo_annotations: MutableSequence["EntityAnnotation"] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message="EntityAnnotation",
     )
-    label_annotations = proto.RepeatedField(
+    label_annotations: MutableSequence["EntityAnnotation"] = proto.RepeatedField(
         proto.MESSAGE,
         number=4,
         message="EntityAnnotation",
     )
-    text_annotations = proto.RepeatedField(
+    text_annotations: MutableSequence["EntityAnnotation"] = proto.RepeatedField(
         proto.MESSAGE,
         number=5,
         message="EntityAnnotation",
     )
-    full_text_annotation = proto.Field(
+    full_text_annotation: text_annotation.TextAnnotation = proto.Field(
         proto.MESSAGE,
         number=12,
         message=text_annotation.TextAnnotation,
     )
-    safe_search_annotation = proto.Field(
+    safe_search_annotation: "SafeSearchAnnotation" = proto.Field(
         proto.MESSAGE,
         number=6,
         message="SafeSearchAnnotation",
     )
-    image_properties_annotation = proto.Field(
+    image_properties_annotation: "ImageProperties" = proto.Field(
         proto.MESSAGE,
         number=8,
         message="ImageProperties",
     )
-    crop_hints_annotation = proto.Field(
+    crop_hints_annotation: "CropHintsAnnotation" = proto.Field(
         proto.MESSAGE,
         number=11,
         message="CropHintsAnnotation",
     )
-    web_detection = proto.Field(
+    web_detection: gcv_web_detection.WebDetection = proto.Field(
         proto.MESSAGE,
         number=13,
         message=gcv_web_detection.WebDetection,
     )
-    error = proto.Field(
+    error: status_pb2.Status = proto.Field(
         proto.MESSAGE,
         number=9,
         message=status_pb2.Status,
@@ -925,12 +1051,12 @@ class BatchAnnotateImagesRequest(proto.Message):
     service call.
 
     Attributes:
-        requests (Sequence[google.cloud.vision_v1p1beta1.types.AnnotateImageRequest]):
+        requests (MutableSequence[google.cloud.vision_v1p1beta1.types.AnnotateImageRequest]):
             Required. Individual image annotation
             requests for this batch.
     """
 
-    requests = proto.RepeatedField(
+    requests: MutableSequence["AnnotateImageRequest"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="AnnotateImageRequest",
@@ -941,12 +1067,12 @@ class BatchAnnotateImagesResponse(proto.Message):
     r"""Response to a batch image annotation request.
 
     Attributes:
-        responses (Sequence[google.cloud.vision_v1p1beta1.types.AnnotateImageResponse]):
+        responses (MutableSequence[google.cloud.vision_v1p1beta1.types.AnnotateImageResponse]):
             Individual responses to image annotation
             requests within the batch.
     """
 
-    responses = proto.RepeatedField(
+    responses: MutableSequence["AnnotateImageResponse"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="AnnotateImageResponse",
