@@ -16,8 +16,20 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
+
+from google.cloud.vision_v1p2beta1 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -40,6 +52,7 @@ from google.cloud.vision_v1p2beta1.types import image_annotator
 from .transports.base import ImageAnnotatorTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ImageAnnotatorGrpcTransport
 from .transports.grpc_asyncio import ImageAnnotatorGrpcAsyncIOTransport
+from .transports.rest import ImageAnnotatorRestTransport
 
 
 class ImageAnnotatorClientMeta(type):
@@ -55,10 +68,11 @@ class ImageAnnotatorClientMeta(type):
     )  # type: Dict[str, Type[ImageAnnotatorTransport]]
     _transport_registry["grpc"] = ImageAnnotatorGrpcTransport
     _transport_registry["grpc_asyncio"] = ImageAnnotatorGrpcAsyncIOTransport
+    _transport_registry["rest"] = ImageAnnotatorRestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[ImageAnnotatorTransport]:
         """Returns an appropriate transport class.
 
@@ -260,7 +274,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -315,8 +329,8 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, ImageAnnotatorTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, ImageAnnotatorTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the image annotator client.
@@ -330,7 +344,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             transport (Union[str, ImageAnnotatorTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -360,6 +374,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -412,11 +427,15 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     def batch_annotate_images(
         self,
-        request: Union[image_annotator.BatchAnnotateImagesRequest, dict] = None,
+        request: Optional[
+            Union[image_annotator.BatchAnnotateImagesRequest, dict]
+        ] = None,
         *,
-        requests: Sequence[image_annotator.AnnotateImageRequest] = None,
+        requests: Optional[
+            MutableSequence[image_annotator.AnnotateImageRequest]
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> image_annotator.BatchAnnotateImagesResponse:
         r"""Run image detection and annotation for a batch of
@@ -424,6 +443,13 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import vision_v1p2beta1
 
             def sample_batch_annotate_images():
@@ -444,7 +470,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             request (Union[google.cloud.vision_v1p2beta1.types.BatchAnnotateImagesRequest, dict]):
                 The request object. Multiple image annotation requests
                 are batched into a single service call.
-            requests (Sequence[google.cloud.vision_v1p2beta1.types.AnnotateImageRequest]):
+            requests (MutableSequence[google.cloud.vision_v1p2beta1.types.AnnotateImageRequest]):
                 Required. Individual image annotation
                 requests for this batch.
 
@@ -479,9 +505,6 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         # there are no flattened fields.
         if not isinstance(request, image_annotator.BatchAnnotateImagesRequest):
             request = image_annotator.BatchAnnotateImagesRequest(request)
-            if requests is not None:
-                for i in range(len(requests)):
-                    requests[i] = image_annotator.AnnotateImageRequest(requests[i])
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if requests is not None:
@@ -504,11 +527,15 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     def async_batch_annotate_files(
         self,
-        request: Union[image_annotator.AsyncBatchAnnotateFilesRequest, dict] = None,
+        request: Optional[
+            Union[image_annotator.AsyncBatchAnnotateFilesRequest, dict]
+        ] = None,
         *,
-        requests: Sequence[image_annotator.AsyncAnnotateFileRequest] = None,
+        requests: Optional[
+            MutableSequence[image_annotator.AsyncAnnotateFileRequest]
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Run async image detection and annotation for a list of generic
@@ -521,6 +548,13 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import vision_v1p2beta1
 
             def sample_async_batch_annotate_files():
@@ -544,8 +578,9 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         Args:
             request (Union[google.cloud.vision_v1p2beta1.types.AsyncBatchAnnotateFilesRequest, dict]):
                 The request object. Multiple async file annotation
-                requests are batched into a single service call.
-            requests (Sequence[google.cloud.vision_v1p2beta1.types.AsyncAnnotateFileRequest]):
+                requests are batched into a single
+                service call.
+            requests (MutableSequence[google.cloud.vision_v1p2beta1.types.AsyncAnnotateFileRequest]):
                 Required. Individual async file
                 annotation requests for this batch.
 
@@ -583,9 +618,6 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         # there are no flattened fields.
         if not isinstance(request, image_annotator.AsyncBatchAnnotateFilesRequest):
             request = image_annotator.AsyncBatchAnnotateFilesRequest(request)
-            if requests is not None:
-                for i in range(len(requests)):
-                    requests[i] = image_annotator.AsyncAnnotateFileRequest(requests[i])
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if requests is not None:
@@ -616,7 +648,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "ImageAnnotatorClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -630,14 +662,9 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-vision",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ImageAnnotatorClient",)
