@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,22 +13,26 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from typing import Dict, Type
 
 from .base import ProductSearchTransport
 from .grpc import ProductSearchGrpcTransport
 from .grpc_asyncio import ProductSearchGrpcAsyncIOTransport
+from .rest import ProductSearchRestTransport
+from .rest import ProductSearchRestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ProductSearchTransport]]
 _transport_registry["grpc"] = ProductSearchGrpcTransport
 _transport_registry["grpc_asyncio"] = ProductSearchGrpcAsyncIOTransport
+_transport_registry["rest"] = ProductSearchRestTransport
 
 __all__ = (
     "ProductSearchTransport",
     "ProductSearchGrpcTransport",
     "ProductSearchGrpcAsyncIOTransport",
+    "ProductSearchRestTransport",
+    "ProductSearchRestInterceptor",
 )
