@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.vision_v1p4beta1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -129,7 +140,7 @@ class ImageAnnotatorAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -165,9 +176,9 @@ class ImageAnnotatorAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ImageAnnotatorTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the image annotator client.
@@ -211,11 +222,15 @@ class ImageAnnotatorAsyncClient:
 
     async def batch_annotate_images(
         self,
-        request: Union[image_annotator.BatchAnnotateImagesRequest, dict] = None,
+        request: Optional[
+            Union[image_annotator.BatchAnnotateImagesRequest, dict]
+        ] = None,
         *,
-        requests: Sequence[image_annotator.AnnotateImageRequest] = None,
+        requests: Optional[
+            MutableSequence[image_annotator.AnnotateImageRequest]
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> image_annotator.BatchAnnotateImagesResponse:
         r"""Run image detection and annotation for a batch of
@@ -223,6 +238,13 @@ class ImageAnnotatorAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import vision_v1p4beta1
 
             async def sample_batch_annotate_images():
@@ -240,10 +262,10 @@ class ImageAnnotatorAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.vision_v1p4beta1.types.BatchAnnotateImagesRequest, dict]):
+            request (Optional[Union[google.cloud.vision_v1p4beta1.types.BatchAnnotateImagesRequest, dict]]):
                 The request object. Multiple image annotation requests
                 are batched into a single service call.
-            requests (:class:`Sequence[google.cloud.vision_v1p4beta1.types.AnnotateImageRequest]`):
+            requests (:class:`MutableSequence[google.cloud.vision_v1p4beta1.types.AnnotateImageRequest]`):
                 Required. Individual image annotation
                 requests for this batch.
 
@@ -307,11 +329,13 @@ class ImageAnnotatorAsyncClient:
 
     async def batch_annotate_files(
         self,
-        request: Union[image_annotator.BatchAnnotateFilesRequest, dict] = None,
+        request: Optional[
+            Union[image_annotator.BatchAnnotateFilesRequest, dict]
+        ] = None,
         *,
-        requests: Sequence[image_annotator.AnnotateFileRequest] = None,
+        requests: Optional[MutableSequence[image_annotator.AnnotateFileRequest]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> image_annotator.BatchAnnotateFilesResponse:
         r"""Service that performs image detection and annotation
@@ -325,6 +349,13 @@ class ImageAnnotatorAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import vision_v1p4beta1
 
             async def sample_batch_annotate_files():
@@ -342,10 +373,10 @@ class ImageAnnotatorAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.vision_v1p4beta1.types.BatchAnnotateFilesRequest, dict]):
+            request (Optional[Union[google.cloud.vision_v1p4beta1.types.BatchAnnotateFilesRequest, dict]]):
                 The request object. A list of requests to annotate files
                 using the BatchAnnotateFiles API.
-            requests (:class:`Sequence[google.cloud.vision_v1p4beta1.types.AnnotateFileRequest]`):
+            requests (:class:`MutableSequence[google.cloud.vision_v1p4beta1.types.AnnotateFileRequest]`):
                 Required. The list of file annotation
                 requests. Right now we support only one
                 AnnotateFileRequest in
@@ -409,12 +440,16 @@ class ImageAnnotatorAsyncClient:
 
     async def async_batch_annotate_images(
         self,
-        request: Union[image_annotator.AsyncBatchAnnotateImagesRequest, dict] = None,
+        request: Optional[
+            Union[image_annotator.AsyncBatchAnnotateImagesRequest, dict]
+        ] = None,
         *,
-        requests: Sequence[image_annotator.AnnotateImageRequest] = None,
-        output_config: image_annotator.OutputConfig = None,
+        requests: Optional[
+            MutableSequence[image_annotator.AnnotateImageRequest]
+        ] = None,
+        output_config: Optional[image_annotator.OutputConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Run asynchronous image detection and annotation for a list of
@@ -432,6 +467,13 @@ class ImageAnnotatorAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import vision_v1p4beta1
 
             async def sample_async_batch_annotate_images():
@@ -447,16 +489,16 @@ class ImageAnnotatorAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.vision_v1p4beta1.types.AsyncBatchAnnotateImagesRequest, dict]):
+            request (Optional[Union[google.cloud.vision_v1p4beta1.types.AsyncBatchAnnotateImagesRequest, dict]]):
                 The request object. Request for async image annotation
                 for a list of images.
-            requests (:class:`Sequence[google.cloud.vision_v1p4beta1.types.AnnotateImageRequest]`):
+            requests (:class:`MutableSequence[google.cloud.vision_v1p4beta1.types.AnnotateImageRequest]`):
                 Required. Individual image annotation
                 requests for this batch.
 
@@ -540,11 +582,15 @@ class ImageAnnotatorAsyncClient:
 
     async def async_batch_annotate_files(
         self,
-        request: Union[image_annotator.AsyncBatchAnnotateFilesRequest, dict] = None,
+        request: Optional[
+            Union[image_annotator.AsyncBatchAnnotateFilesRequest, dict]
+        ] = None,
         *,
-        requests: Sequence[image_annotator.AsyncAnnotateFileRequest] = None,
+        requests: Optional[
+            MutableSequence[image_annotator.AsyncAnnotateFileRequest]
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Run asynchronous image detection and annotation for a list of
@@ -557,6 +603,13 @@ class ImageAnnotatorAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import vision_v1p4beta1
 
             async def sample_async_batch_annotate_files():
@@ -572,16 +625,17 @@ class ImageAnnotatorAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.vision_v1p4beta1.types.AsyncBatchAnnotateFilesRequest, dict]):
+            request (Optional[Union[google.cloud.vision_v1p4beta1.types.AsyncBatchAnnotateFilesRequest, dict]]):
                 The request object. Multiple async file annotation
-                requests are batched into a single service call.
-            requests (:class:`Sequence[google.cloud.vision_v1p4beta1.types.AsyncAnnotateFileRequest]`):
+                requests are batched into a single
+                service call.
+            requests (:class:`MutableSequence[google.cloud.vision_v1p4beta1.types.AsyncAnnotateFileRequest]`):
                 Required. Individual async file
                 annotation requests for this batch.
 
@@ -654,21 +708,16 @@ class ImageAnnotatorAsyncClient:
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "ImageAnnotatorAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-vision",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ImageAnnotatorAsyncClient",)
