@@ -18,16 +18,23 @@ import os
 # try/except added for compatibility with python < 3.8
 try:
     from unittest import mock
-    from unittest.mock import AsyncMock
-except ImportError:
+    from unittest.mock import AsyncMock  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
     import mock
 
 import grpc
 from grpc.experimental import aio
+from collections.abc import Iterable
+from google.protobuf import json_format
+import json
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+from proto.marshal.rules import wrappers
+from requests import Response
+from requests import Request, PreparedRequest
+from requests.sessions import Session
+from google.protobuf import json_format
 
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
@@ -97,6 +104,7 @@ def test__get_default_mtls_endpoint():
     [
         (ImageAnnotatorClient, "grpc"),
         (ImageAnnotatorAsyncClient, "grpc_asyncio"),
+        (ImageAnnotatorClient, "rest"),
     ],
 )
 def test_image_annotator_client_from_service_account_info(client_class, transport_name):
@@ -110,7 +118,11 @@ def test_image_annotator_client_from_service_account_info(client_class, transpor
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("vision.googleapis.com:443")
+        assert client.transport._host == (
+            "vision.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://vision.googleapis.com"
+        )
 
 
 @pytest.mark.parametrize(
@@ -118,6 +130,7 @@ def test_image_annotator_client_from_service_account_info(client_class, transpor
     [
         (transports.ImageAnnotatorGrpcTransport, "grpc"),
         (transports.ImageAnnotatorGrpcAsyncIOTransport, "grpc_asyncio"),
+        (transports.ImageAnnotatorRestTransport, "rest"),
     ],
 )
 def test_image_annotator_client_service_account_always_use_jwt(
@@ -143,6 +156,7 @@ def test_image_annotator_client_service_account_always_use_jwt(
     [
         (ImageAnnotatorClient, "grpc"),
         (ImageAnnotatorAsyncClient, "grpc_asyncio"),
+        (ImageAnnotatorClient, "rest"),
     ],
 )
 def test_image_annotator_client_from_service_account_file(client_class, transport_name):
@@ -163,13 +177,18 @@ def test_image_annotator_client_from_service_account_file(client_class, transpor
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("vision.googleapis.com:443")
+        assert client.transport._host == (
+            "vision.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://vision.googleapis.com"
+        )
 
 
 def test_image_annotator_client_get_transport_class():
     transport = ImageAnnotatorClient.get_transport_class()
     available_transports = [
         transports.ImageAnnotatorGrpcTransport,
+        transports.ImageAnnotatorRestTransport,
     ]
     assert transport in available_transports
 
@@ -186,6 +205,7 @@ def test_image_annotator_client_get_transport_class():
             transports.ImageAnnotatorGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (ImageAnnotatorClient, transports.ImageAnnotatorRestTransport, "rest"),
     ],
 )
 @mock.patch.object(
@@ -331,6 +351,8 @@ def test_image_annotator_client_client_options(
             "grpc_asyncio",
             "false",
         ),
+        (ImageAnnotatorClient, transports.ImageAnnotatorRestTransport, "rest", "true"),
+        (ImageAnnotatorClient, transports.ImageAnnotatorRestTransport, "rest", "false"),
     ],
 )
 @mock.patch.object(
@@ -530,6 +552,7 @@ def test_image_annotator_client_get_mtls_endpoint_and_cert_source(client_class):
             transports.ImageAnnotatorGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (ImageAnnotatorClient, transports.ImageAnnotatorRestTransport, "rest"),
     ],
 )
 def test_image_annotator_client_client_options_scopes(
@@ -570,6 +593,7 @@ def test_image_annotator_client_client_options_scopes(
             "grpc_asyncio",
             grpc_helpers_async,
         ),
+        (ImageAnnotatorClient, transports.ImageAnnotatorRestTransport, "rest", None),
     ],
 )
 def test_image_annotator_client_client_options_credentials_file(
@@ -885,6 +909,275 @@ async def test_batch_annotate_images_flattened_error_async():
         )
 
 
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        image_annotator.BatchAnnotateImagesRequest,
+        dict,
+    ],
+)
+def test_batch_annotate_images_rest(request_type):
+    client = ImageAnnotatorClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = image_annotator.BatchAnnotateImagesResponse()
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = image_annotator.BatchAnnotateImagesResponse.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.batch_annotate_images(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, image_annotator.BatchAnnotateImagesResponse)
+
+
+def test_batch_annotate_images_rest_required_fields(
+    request_type=image_annotator.BatchAnnotateImagesRequest,
+):
+    transport_class = transports.ImageAnnotatorRestTransport
+
+    request_init = {}
+    request = request_type(**request_init)
+    pb_request = request_type.pb(request)
+    jsonified_request = json.loads(
+        json_format.MessageToJson(
+            pb_request,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
+        )
+    )
+
+    # verify fields with default values are dropped
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).batch_annotate_images._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with default values are now present
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).batch_annotate_images._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with non-default values are left alone
+
+    client = ImageAnnotatorClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    request = request_type(**request_init)
+
+    # Designate an appropriate value for the returned response.
+    return_value = image_annotator.BatchAnnotateImagesResponse()
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(Session, "request") as req:
+        # We need to mock transcode() because providing default values
+        # for required fields will fail the real version if the http_options
+        # expect actual values for those fields.
+        with mock.patch.object(path_template, "transcode") as transcode:
+            # A uri without fields and an empty body will force all the
+            # request fields to show up in the query_params.
+            pb_request = request_type.pb(request)
+            transcode_result = {
+                "uri": "v1/sample_method",
+                "method": "post",
+                "query_params": pb_request,
+            }
+            transcode_result["body"] = pb_request
+            transcode.return_value = transcode_result
+
+            response_value = Response()
+            response_value.status_code = 200
+
+            pb_return_value = image_annotator.BatchAnnotateImagesResponse.pb(
+                return_value
+            )
+            json_return_value = json_format.MessageToJson(pb_return_value)
+
+            response_value._content = json_return_value.encode("UTF-8")
+            req.return_value = response_value
+
+            response = client.batch_annotate_images(request)
+
+            expected_params = [("$alt", "json;enum-encoding=int")]
+            actual_params = req.call_args.kwargs["params"]
+            assert expected_params == actual_params
+
+
+def test_batch_annotate_images_rest_unset_required_fields():
+    transport = transports.ImageAnnotatorRestTransport(
+        credentials=ga_credentials.AnonymousCredentials
+    )
+
+    unset_fields = transport.batch_annotate_images._get_unset_required_fields({})
+    assert set(unset_fields) == (set(()) & set(("requests",)))
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_batch_annotate_images_rest_interceptors(null_interceptor):
+    transport = transports.ImageAnnotatorRestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.ImageAnnotatorRestInterceptor(),
+    )
+    client = ImageAnnotatorClient(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        transports.ImageAnnotatorRestInterceptor, "post_batch_annotate_images"
+    ) as post, mock.patch.object(
+        transports.ImageAnnotatorRestInterceptor, "pre_batch_annotate_images"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = image_annotator.BatchAnnotateImagesRequest.pb(
+            image_annotator.BatchAnnotateImagesRequest()
+        )
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = image_annotator.BatchAnnotateImagesResponse.to_json(
+            image_annotator.BatchAnnotateImagesResponse()
+        )
+
+        request = image_annotator.BatchAnnotateImagesRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = image_annotator.BatchAnnotateImagesResponse()
+
+        client.batch_annotate_images(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_batch_annotate_images_rest_bad_request(
+    transport: str = "rest", request_type=image_annotator.BatchAnnotateImagesRequest
+):
+    client = ImageAnnotatorClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.batch_annotate_images(request)
+
+
+def test_batch_annotate_images_rest_flattened():
+    client = ImageAnnotatorClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = image_annotator.BatchAnnotateImagesResponse()
+
+        # get arguments that satisfy an http rule for this method
+        sample_request = {}
+
+        # get truthy value for each flattened field
+        mock_args = dict(
+            requests=[
+                image_annotator.AnnotateImageRequest(
+                    image=image_annotator.Image(content=b"content_blob")
+                )
+            ],
+        )
+        mock_args.update(sample_request)
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = image_annotator.BatchAnnotateImagesResponse.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+
+        client.batch_annotate_images(**mock_args)
+
+        # Establish that the underlying call was made with the expected
+        # request object values.
+        assert len(req.mock_calls) == 1
+        _, args, _ = req.mock_calls[0]
+        assert path_template.validate(
+            "%s/v1p1beta1/images:annotate" % client.transport._host, args[1]
+        )
+
+
+def test_batch_annotate_images_rest_flattened_error(transport: str = "rest"):
+    client = ImageAnnotatorClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # Attempting to call a method with both a request object and flattened
+    # fields is an error.
+    with pytest.raises(ValueError):
+        client.batch_annotate_images(
+            image_annotator.BatchAnnotateImagesRequest(),
+            requests=[
+                image_annotator.AnnotateImageRequest(
+                    image=image_annotator.Image(content=b"content_blob")
+                )
+            ],
+        )
+
+
+def test_batch_annotate_images_rest_error():
+    client = ImageAnnotatorClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport="rest"
+    )
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.ImageAnnotatorGrpcTransport(
@@ -966,6 +1259,7 @@ def test_transport_get_channel():
     [
         transports.ImageAnnotatorGrpcTransport,
         transports.ImageAnnotatorGrpcAsyncIOTransport,
+        transports.ImageAnnotatorRestTransport,
     ],
 )
 def test_transport_adc(transport_class):
@@ -980,6 +1274,7 @@ def test_transport_adc(transport_class):
     "transport_name",
     [
         "grpc",
+        "rest",
     ],
 )
 def test_transport_kind(transport_name):
@@ -1116,6 +1411,7 @@ def test_image_annotator_transport_auth_adc(transport_class):
     [
         transports.ImageAnnotatorGrpcTransport,
         transports.ImageAnnotatorGrpcAsyncIOTransport,
+        transports.ImageAnnotatorRestTransport,
     ],
 )
 def test_image_annotator_transport_auth_gdch_credentials(transport_class):
@@ -1216,11 +1512,23 @@ def test_image_annotator_grpc_transport_client_cert_source_for_mtls(transport_cl
             )
 
 
+def test_image_annotator_http_transport_client_cert_source_for_mtls():
+    cred = ga_credentials.AnonymousCredentials()
+    with mock.patch(
+        "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
+    ) as mock_configure_mtls_channel:
+        transports.ImageAnnotatorRestTransport(
+            credentials=cred, client_cert_source_for_mtls=client_cert_source_callback
+        )
+        mock_configure_mtls_channel.assert_called_once_with(client_cert_source_callback)
+
+
 @pytest.mark.parametrize(
     "transport_name",
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_image_annotator_host_no_port(transport_name):
@@ -1231,7 +1539,11 @@ def test_image_annotator_host_no_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("vision.googleapis.com:443")
+    assert client.transport._host == (
+        "vision.googleapis.com:443"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://vision.googleapis.com"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1239,6 +1551,7 @@ def test_image_annotator_host_no_port(transport_name):
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_image_annotator_host_with_port(transport_name):
@@ -1249,7 +1562,33 @@ def test_image_annotator_host_with_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("vision.googleapis.com:8000")
+    assert client.transport._host == (
+        "vision.googleapis.com:8000"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://vision.googleapis.com:8000"
+    )
+
+
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_image_annotator_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = ImageAnnotatorClient(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = ImageAnnotatorClient(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.batch_annotate_images._session
+    session2 = client2.transport.batch_annotate_images._session
+    assert session1 != session2
 
 
 def test_image_annotator_grpc_transport_channel():
@@ -1520,6 +1859,7 @@ async def test_transport_close_async():
 
 def test_transport_close():
     transports = {
+        "rest": "_session",
         "grpc": "_grpc_channel",
     }
 
@@ -1537,6 +1877,7 @@ def test_transport_close():
 
 def test_client_ctx():
     transports = [
+        "rest",
         "grpc",
     ]
     for transport in transports:
